==> open-cluster-management-operator-model-6.0.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/MultiClusterHubStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface MultiClusterHubStatusFluent<A extends MultiClusterHubStatusFluent<A>> extends Fluent<A>{
  public A addToComponents(String key,StatusCondition value);
  public A addToComponents(Map<String,StatusCondition> map);
  public A removeFromComponents(String key);
  public A removeFromComponents(Map<String,StatusCondition> map);
  public Map<String,StatusCondition> getComponents();
  public <K,V>A withComponents(Map<String,StatusCondition> components);
  public Boolean hasComponents();
  public A addToConditions(Integer index,HubCondition item);
  public A setToConditions(Integer index,HubCondition item);
  public A addToConditions(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition... items);
  public A addAllToConditions(Collection<HubCondition> items);
  public A removeFromConditions(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition... items);
  public A removeAllFromConditions(Collection<HubCondition> items);
  public A removeMatchingFromConditions(Predicate<HubConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HubCondition> getConditions();
  public List<HubCondition> buildConditions();
  public HubCondition buildCondition(Integer index);
  public HubCondition buildFirstCondition();
  public HubCondition buildLastCondition();
  public HubCondition buildMatchingCondition(Predicate<HubConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<HubConditionBuilder> predicate);
  public A withConditions(List<HubCondition> conditions);
  public A withConditions(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition... conditions);
  public Boolean hasConditions();
  public MultiClusterHubStatusFluent.ConditionsNested<A> addNewCondition();
  public MultiClusterHubStatusFluent.ConditionsNested<A> addNewConditionLike(HubCondition item);
  public MultiClusterHubStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,HubCondition item);
  public MultiClusterHubStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public MultiClusterHubStatusFluent.ConditionsNested<A> editFirstCondition();
  public MultiClusterHubStatusFluent.ConditionsNested<A> editLastCondition();
  public MultiClusterHubStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<HubConditionBuilder> predicate);
  public String getCurrentVersion();
  public A withCurrentVersion(String currentVersion);
  public Boolean hasCurrentVersion();
  public String getDesiredVersion();
  public A withDesiredVersion(String desiredVersion);
  public Boolean hasDesiredVersion();
  public String getPhase();
  public A withPhase(String phase);
  public Boolean hasPhase();
  public interface ConditionsNested<N> extends Nested<N>,HubConditionFluent<MultiClusterHubStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> open-cluster-management-operator-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/MultiClusterHubStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface MultiClusterHubStatusFluent<A extends MultiClusterHubStatusFluent<A>> extends Fluent<A>{
  public A addToComponents(String key,StatusCondition value);
  public A addToComponents(Map<String,StatusCondition> map);
  public A removeFromComponents(String key);
  public A removeFromComponents(Map<String,StatusCondition> map);
  public Map<String,StatusCondition> getComponents();
  public <K,V>A withComponents(Map<String,StatusCondition> components);
  public Boolean hasComponents();
  public A addToConditions(int index,HubCondition item);
  public A setToConditions(int index,HubCondition item);
  public A addToConditions(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition... items);
  public A addAllToConditions(Collection<HubCondition> items);
  public A removeFromConditions(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition... items);
  public A removeAllFromConditions(Collection<HubCondition> items);
  public A removeMatchingFromConditions(Predicate<HubConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HubCondition> getConditions();
  public List<HubCondition> buildConditions();
  public HubCondition buildCondition(int index);
  public HubCondition buildFirstCondition();
  public HubCondition buildLastCondition();
  public HubCondition buildMatchingCondition(Predicate<HubConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<HubConditionBuilder> predicate);
  public A withConditions(List<HubCondition> conditions);
  public A withConditions(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition... conditions);
  public Boolean hasConditions();
  public MultiClusterHubStatusFluent.ConditionsNested<A> addNewCondition();
  public MultiClusterHubStatusFluent.ConditionsNested<A> addNewConditionLike(HubCondition item);
  public MultiClusterHubStatusFluent.ConditionsNested<A> setNewConditionLike(int index,HubCondition item);
  public MultiClusterHubStatusFluent.ConditionsNested<A> editCondition(int index);
  public MultiClusterHubStatusFluent.ConditionsNested<A> editFirstCondition();
  public MultiClusterHubStatusFluent.ConditionsNested<A> editLastCondition();
  public MultiClusterHubStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<HubConditionBuilder> predicate);
  public String getCurrentVersion();
  public A withCurrentVersion(String currentVersion);
  public Boolean hasCurrentVersion();
  public String getDesiredVersion();
  public A withDesiredVersion(String desiredVersion);
  public Boolean hasDesiredVersion();
  public String getPhase();
  public A withPhase(String phase);
  public Boolean hasPhase();
  public interface ConditionsNested<N> extends Nested<N>,HubConditionFluent<MultiClusterHubStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
